local L = LibStub("AceLocale-3.0"):GetLocale("SunnArt", true)

SunnArt_OPTIONS = { 
		name = "SunnArt",
		handler = SunnArt,
		type="group",
		args = {
		   artwork = {
				name = L["Artwork"],
				type = "toggle",
				desc = L["Enable or Disable artwork in the panels"],
				get = function(info)
					return SunnArt.db.profile.artwork
				end,
				set = function(info,a)
  					SunnArt:Disable()
					SunnArt.db.profile.artwork=a
					SunnArt:Enable()
				end,
				order = 1,
			},
			theme = {
				name = L["Theme"],
				type = "select",
				desc = L["Graphical theme"],
				get = function(info)
					return SunnArt.db.profile.Theme
				end,
				set = function(info,name)
  					SunnArt:Disable()
					SunnArt.db.profile.Theme=name
					SunnArt.db.profile.rotatetop=true
					SunnArt:Enable()
				end,
				values = {["SunnArt\\forsaken"] = "Forsaken", ["SunnArt\\tribal"] = "Tribal",["SunnArt\\royal"] = "Royal",["SunnArt\\rogue"] = "Rogue",["solid"] = "Solid colour"},
				style = "dropdown",
				order = 2,
			},
			colourselect = {
				type = "color",
				order = 3,
				name = L["Solid colour"],
				desc = L["Colour of the Solid Colour theme"],
				get = function(info)
					return SunnArt.db.profile.colourred,SunnArt.db.profile.colourgreen,SunnArt.db.profile.colourblue
				end,
				set = function(info,r,g,b)
  					SunnArt:Disable()
					SunnArt.db.profile.colourred = r
					SunnArt.db.profile.colourgreen = g
					SunnArt.db.profile.colourblue = b
					SunnArt.db.profile.Theme = "solid"
					SunnArt:Enable()
				end,
			},
			globalspacer = {
				order = 4,
				type = "header",
				name = L["Viewport Settings"],
			},
			horizviewport = {
				name = L["Horizontal Viewport"],
				type = "toggle",
				desc = L["Enable or Disable the viewport Horizontally"],
				get = function(info)
					return (SunnArt.db.profile.leftviewport and SunnArt.db.profile.rightviewport)
				end,
				set = function(info,v)
					SunnArt.db.profile.leftviewport=v
					SunnArt.db.profile.rightviewport=v
					SunnArt:UpdateViewport()
				end,
				order = 5,
			},
			vertviewport = {
				name = L["Vertical Viewport"],
				type = "toggle",
				desc = L["Enable or Disable the viewport Vertically"],
				get = function(info)
					return (SunnArt.db.profile.topviewport and SunnArt.db.profile.bottomviewport)
				end,
				set = function(info,v)
					SunnArt.db.profile.topviewport=v
					SunnArt.db.profile.bottomviewport=v
					SunnArt:UpdateViewport()
				end,
				order=6,
			},
		   spacer = {
				order = 10,
				type = "header",
				name = L["Artwork Panels"],
			},				
			top = {
				order = 11,
				type = "group",
				name = L["Top panel"],
				desc = L["Top panel properties"],
				args = {
					size = {
						order = 1,
						type = "range",
						name = L["Panel thickness"],
						desc = L["Change the thickness of this panel (percentage of screen)"],
						min = 0,
						max = 100,
						step = 0.1,
						get = function(info)
							return SunnArt.db.profile.topbar
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.topbar=v
							SunnArt:Enable()
						end,
					},
					alpha = {
						order = 2,
						type = "range",
						name = L["Artwork transparency"],
						desc = L["Transparency of the panel artwork"],
						min=0,
						max=1,
						step= 0.02,
						get = function(info)
							return SunnArt.db.profile.topalpha
						end,
						set = function(info,v)
							SunnArt.db.profile.topalpha=v
							SunnArt:UpdateAlpha()
						end,
					},
					resize = {
						order = 4,
						name = L["Resize Viewport"],
						type = "toggle",
						desc = L["Toggle Overlay/Viewport mode for this panel"],
						get = function(info)
							return (SunnArt.db.profile.topviewport)
						end,
						set = function(info,v)
							SunnArt.db.profile.topviewport=(v)
							SunnArt:UpdateViewport()
						end,
					},
					scale = {
						order = 3,
						type = "range",
						name = L["Artwork scale"],
						desc = L["Maximum scale of the artwork before stretching occurs"],
						min = 0,
						max = 2,
						step = 0.02,
						get = function(info)
							return SunnArt.db.profile.topscale
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.topscale=v
							SunnArt:Enable()
						end,
					},
					rotate = {
						order = 5,
						type = "toggle",
						name = L["Rotate Panel"],
						desc = L["Rotate the panel so the artwork appears upside down"],
						get = function(info)
							return SunnArt.db.profile.rotatetop
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.rotatetop=v
							SunnArt:Enable()
						end,
					},
					reset = {
						order = 9,
						type = "execute",
						name = L["Reset"],
						desc = L["Restore default values"],
						func = function(info)
  							SunnArt:Disable()
							SunnArt.db.profile.topbar = 2.6
							SunnArt.db.profile.topalpha=1.0
							SunnArt.db.profile.topviewport = false
							SunnArt.db.profile.topscale = 0.58
							SunnArt.db.profile.autostretchtop = true
							SunnArt.db.profile.rotatetop = true
							SunnArt:Enable()
						end,
					},
				},
			},
			bottom = {
				order = 12,
				type = "group",
				name = L["Bottom panel"],
				desc = L["Bottom panel properties"],
				args = {
					size = {
						order = 1,
						type = "range",
						name = L["Panel thickness"],
						desc = L["Change the thickness of this panel (percentage of screen)"],
						min = 0,
						max = 100,
						step = 0.1,
						get = function(info)
							return SunnArt.db.profile.bottombar
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.bottombar=v
							SunnArt:Enable()
						end,
					},
					alpha = {
						order = 2,
						type = "range",
						name = L["Artwork transparency"],
						desc = L["Transparency of the panel artwork"],
						min=0,
						max=1,
						step=0.02,
						get = function(info)
							return SunnArt.db.profile.bottomalpha
						end,
						set = function(info,v)
							SunnArt.db.profile.bottomalpha=v
							SunnArt:UpdateAlpha()
						end,
					},
					resize = {
						order = 4,
						name = L["Resize Viewport"],
						type = "toggle",
						desc = L["Toggle Overlay/Viewport mode for this panel"],
						get = function(info)
							return (SunnArt.db.profile.bottomviewport)
						end,
						set = function(info,v)
							SunnArt.db.profile.bottomviewport=(v)
							SunnArt:UpdateViewport()
						end,
					},
					scale = {
						order = 3,
						type = "range",
						name = L["Artwork scale"],
						desc = L["Maximum scale of the artwork before stretching occurs"],
						min = 0,
						max = 2,
						step = 0.02,
						get = function(info)
							return SunnArt.db.profile.bottomscale
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.bottomscale=v
							SunnArt:Enable()
						end,
					},
					reset = {
						order = 9,
						type = "execute",
						name = L["Reset"],
						desc = L["Restore default values"],
						func = function(info)
  							SunnArt:Disable()
							SunnArt.db.profile.bottombar = 20
							SunnArt.db.profile.bottomalpha=1.0
							SunnArt.db.profile.bottomviewport = false
							SunnArt.db.profile.bottomscale = 1
							SunnArt.db.profile.autostretchbottom = true
							SunnArt:Enable()
						end,
					},
				},
			},
			left = {
				order = 13,
				type = "group",
				name = L["Left panel"],
				desc = L["Left panel properties"],
				args = {
					size = {
						order = 1,
						type = "range",
						name = L["Panel thickness"],
						desc = L["Change the thickness of this panel (percentage of screen)"],
						min = 0,
						max = 100,
						step = 0.1,
						get = function(info)
							return SunnArt.db.profile.leftbar
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.leftbar=v
							SunnArt:Enable()
						end,
					},
					alpha = {
						order = 2,
						type = "range",
						name = L["Artwork transparency"],
						desc = L["Transparency of the panel artwork"],
						min=0,
						max=1,
						step=0.02,
						get = function(info)
							return SunnArt.db.profile.leftalpha
						end,
						set = function(info,v)
							SunnArt.db.profile.leftalpha=v
							SunnArt:UpdateAlpha()
						end,
					},
					resize = {
						order = 4,
						name = L["Resize Viewport"],
						type = "toggle",
						desc = L["Toggle Overlay/Viewport mode for this panel"],
						get = function(info)
							return (SunnArt.db.profile.leftviewport)
						end,
						set = function(info,v)
							SunnArt.db.profile.leftviewport=(v)
							SunnArt:UpdateViewport()
						end,
					},
					scale = {
						order = 3,
						type = "range",
						name = L["Artwork scale"],
						desc = L["Maximum scale of the artwork before stretching occurs"],
						min = 0,
						max = 2,
						step = 0.02,
						get = function(info)
							return SunnArt.db.profile.leftscale
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.leftscale=v
							SunnArt:Enable()
						end,
					},
					reset = {
						order = 9,
						type = "execute",
						name = L["Reset"],
						desc = L["Restore default values"],
						func = function(info)
  							SunnArt:Disable()
							SunnArt.db.profile.leftbar = 0
							SunnArt.db.profile.leftalpha = 1.0
							SunnArt.db.profile.leftviewport = false
							SunnArt.db.profile.leftscale = 1
							SunnArt.db.profile.autostretchleft = true
							SunnArt:Enable()
						end,
					},
				},
			},
			right = {
				order = 14,
				type = "group",
				name = L["Right panel"],
				desc = L["Right panel properties"],
				args = {
					size = {
						order = 1,
						type = "range",
						name = L["Panel thickness"],
						desc = L["Change the thickness of this panel (percentage of screen)"],
						min = 0,
						max = 100,
						step = 0.1,
						get = function(info)
							return SunnArt.db.profile.rightbar
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.rightbar=v
							SunnArt:Enable()
						end,
					},
					alpha = {
						order = 2,
						type = "range",
						name = L["Artwork transparency"],
						desc = L["Transparency of the panel artwork"],
						min=0,
						max=1,
						step=0.02,
						get = function(info)
							return SunnArt.db.profile.rightalpha
						end,
						set = function(info,v)
							SunnArt.db.profile.rightalpha=v
							SunnArt:UpdateAlpha()
						end,
					},
					resize = {
						order = 4,
						name = L["Resize Viewport"],
						type = "toggle",
						desc = L["Toggle Overlay/Viewport mode for this panel"],
						get = function(info)
							return (SunnArt.db.profile.rightviewport)
						end,
						set = function(info,v)
							SunnArt.db.profile.rightviewport=(v)
							SunnArt:UpdateViewport()
						end,
					},
					scale = {
						order = 3,
						type = "range",
						name = L["Artwork scale"],
						desc = L["Maximum scale of the artwork before stretching occurs"],
						min = 0,
						max = 2,
						step = 0.02,
						get = function(info)
							return SunnArt.db.profile.rightscale
						end,
						set = function(info,v)
  							SunnArt:Disable()
							SunnArt.db.profile.rightscale=v
							SunnArt:Enable()
						end,
					},
					reset = {
						order = 9,
						type = "execute",
						name = L["Reset"],
						desc = L["Restore default values"],
						func = function(info)
  							SunnArt:Disable()
							SunnArt.db.profile.rightbar = 0
							SunnArt.db.profile.rightalpha = 1.0
							SunnArt.db.profile.rightviewport = false
							SunnArt.db.profile.rightscale = 1
							SunnArt.db.profile.autostretchright = true
							SunnArt:Enable()
						end,
					},
				},
			},
			advanced = {
				order = 15,
				type = "group",
				name = L["Advanced"],
				desc = L["Advanced options"],
				args = {					
					framelevels = {
						order = 1,
						type = "group",
						name = L["Frame Levels"],
						desc = L["Frame Levels (Strata)"],
						args = {
							framestrata = {
								order = 1,
								type = "select",
								name = L["Frame Strata"],
								desc = L["Sets the strata (layer depth) of the frames"],
								values = {["BACKGROUND"]="Background",["LOW"]="Low",["MEDIUM"]="Medium",["HIGH"]="High"},
								get = function(info)
									return SunnArt.db.profile.framestrata
								end,
								set = function(info,v)
									SunnArt.db.profile.framestrata = v
									SunnArt.frame1:SetFrameStrata(v)
									SunnArt.frame2:SetFrameStrata(v)
									SunnArt.frame3:SetFrameStrata(v)
									SunnArt.frame4:SetFrameStrata(v)
								end,
							},
							bfframestrata = {
							order = 2,
							type = "select",
							name = L["Battlefield Frame Strata"],
							desc = L["Sets the strata (layer depth) of the battlefield frame"],
							values = {["BACKGROUND"]="Background",["LOW"]="Low",["MEDIUM"]="Medium",["HIGH"]="High"},
							get = function(info)
								return SunnArt.db.profile.bfframestrata
							end,
							set = function(info,v)
								SunnArt.db.profile.bfframestrata = v
								if (BattlefieldMinimap) then 
									BattlefieldMinimap:SetFrameStrata(v)
								end
							end,
							},
						},
					},
					autostretch = {
						order = 15,
						type = "group",
						name = L["Auto-Stretch"],
						desc = L["Auto-Stretch textures to the edge of the screen if the artwork is too narrow"],
						args = {
							top = {
								order = 1,
								name = L["Top panel"],
								type = "toggle",
								desc = L["Toggle auto-stretch for this panel"],
								get = function(info)
									return SunnArt.db.profile.autostretchtop
								end,
								set = function(info,v)
									SunnArt.db.profile.autostretchtop = v
									SunnArt:Enable()
								end,
							},
							bottom = {
								order = 2,
								name = L["Bottom panel"],
								type = "toggle",
								desc = L["Toggle auto-stretch for this panel"],
								get = function(info)
									return SunnArt.db.profile.autostretchbottom
								end,
								set = function(info,v)
									SunnArt.db.profile.autostretchbottom = v
									SunnArt:Enable()
								end,
							},
							left = {
								order = 3,
								name = L["Left panel"],
								type = "toggle",
								desc = L["Toggle auto-stretch for this panel"],
								get = function(info)
									return SunnArt.db.profile.autostretchleft
								end,
								set = function(info,v)
									SunnArt.db.profile.autostretchleft = v
									SunnArt:Enable()
								end,
							},
							right = {
								order = 4,
								name = L["Right panel"],
								type = "toggle",
								desc = L["Toggle auto-stretch for this panel"],
								get = function(info)
									return SunnArt.db.profile.autostretchright
								end,
								set = function(info,v)
									SunnArt.db.profile.autostretchright = v
									SunnArt:Enable()
								end,
							},
						},
					},				
				},
			},
		},
	}